==> v1.4.40.zip: homepage/content/author/jochum.md <==
---
date: 2023-07-09T00:00:00+02:00
title: René Jochum
description: Is an FOSS enthusiast who has been programming since 2002, currently he loves to develop in Go.
address: Nenzing
email: rene@jochum.dev
phone: +43 664 750 77 653
pgp: F2A7235C1ECFD2F7EADB6D1FF7D906F5E51E8E5E
pgppubfile: /static/author/jochum_pub_pgp.asc

img: /static/author/jochum_240x240.png
---
## About me

Social:
I got the Bipolar type 1 diagnosis and have a good life with it, my personal goal in life is to show everyone that it's possible to have a good life with whatever condition you have to fight with.

Technical:
I love to work with Linux, I love Networking I love Programming. If I can FOSS first. Currently my main interest is Cloud computing.

### Knowledge

Programming Languages (in order of preference):

Language      | Years of Knowledge
--------------|-------------------------------------------------------------------------
Go            |      [11+](https://github.com/jochumdev/golxml)
Python        |      [13+](https://github.com/jochumdev/socketrpc)
C++           |      [13+](https://github.com/jochumdev/Warzone-QML-Frontend)
PHP           |      20+
Javascript    |      21+
Visual Basic  |      [21+](http://www.vbarchiv.net/tipps/details.php?id=680)
VB.NET        |      14+
C#            |      [10+](https://github.com/jochumdev/SharpFlame)

Operating Systems: Linux, OS-X, Windows

Languages: German (first language), English (fluent)

### OpenSource Activities

#### 2023: [go-micro - Development of the upcoming V5](https://github.com/go-orb/go-micro)

[me](https://github.com/jochumdev) and [@Davincible](https://github.com/Davincible) work on the next version of go-micro.

#### 2022: [MicroLobby - 3rd gen lobbyserver for Warzone 2100](https://github.com/jochumdev/microlobby)

MicroLobby is the next, next gen lobbyserver for Warzone 2100 after wzlobbserver-ng.

For this I also have written [jo-micro/router](https://git.jochum.dev/jo-micro/router) and [jo-micro/auth2](https://git.jochum.dev/jo-micro/auth2).

#### 2021: [lql+api](https://git.jochum.dev/jochum/lql-api) + LetsCheck for CheckMK

A interface to the LQL of CheckMK + a Mobile App written in flutter.

#### 2018: LXD Module and States are now part of Salt Fluorine [original PR](https://github.com/saltstack/salt/pull/46231)

Finaly the LXD Module and its States are now part of Saltstack Fluorine. :)

#### 2016 [Presentation at the Linuxday Vorarlberg (German)](https://www.youtube.com/watch?v=0WIyYOsSvQw)

I hold a presentation about Saltstack at the Linuxday Vorarlberg.

#### 2016 - 2017: [saltstack-lxd-formula](https://github.com/saltstack-formulas/lxd-formula)

Working on automatic deployed LXD containers - You say **you want** a Website - **you get** a container with a website in it and ofc all its routing and stuff.

#### 2015 - ca. 2018: [LXD](https://linuxcontainers.org/lxd/)

Smaller stuff.
Intodruced the new [Storage API](https://github.com/lxc/lxd/commits/master?author=rene@jochums.at) for BTRFS and big parts of the LVM version.

#### 2009 - current: IRC

In german theres a wording "Girl for everything" - I help where I can under the name "jochum".

#### 2010 - 2015: [Warzone 2100](http://www.wz2100.net/)

Hosting and maintenance of the website.
Intodruced the [buildbot](http://buildbot.wz2100.net/).
Introduced a new [Lobby Server](https://github.com/jochumdev/wzlobbyserver-ng) in Python.

#### 2002 - ca. 2006: [Apachefriends](https://www.apachefriends.org) XAMPP

Smaller scripts, Moderation in the forums and smaller work.

#### 2002: vb@rchiv

[.m3u reader](http://www.vbarchiv.net/tipps/details.php?id=680)
[ID3v2 Tag reader](http://www.vbarchiv.net/tipps/details.php?id=676)

### CAREER SUMMARY

#### Mai 2023: [Institut für Sozialdienste gGbmH](https://ifs.at)

IT Technican.

#### Januar 2022 - June 2022: [Jochum Development](https://jochum.dev)

Freelance Developer.

#### August 2018 - Oktober 2021: [Webmeisterei GmbH](https://webmeisterei.com)

Worked as DevOp

Tools I have been working with:

- Saltstack
- Debian
- Nutanix CE
- MariaDB Galera Cluster
- Check_MK
- Kubernetes with Rancher
- Gitlab
- borgbackup with borgmatic
- HyCU Backup

#### Mai 2018 - June 2018: [Proxmox Server Solutions GmbH](https://www.proxmox.com/en)

Development in Perl, mainly developed a Client for Proxmox Virtual Environment.

- [pmxc](https://github.com/jochumdev/pmxc)
- [pve-client](https://git.proxmox.com/?p=pve-client.git;a=shortlog)

#### November 2016 – January 2017: [Stiftung Maria Ebene](http://mariaebene.at)

Developing interfaces between Apps (SAP / Filemaker / ELGA uvm.).

- [py-restfmclient](https://github.com/jochumdev/py-restfmclient) python client library for Filemaker over [RESTfm](http://restfm.com)

#### August 2015 – October 2016: [Webmeisterei GmbH](https://webmeisterei.com)

Worked as Plone developer.

#### June 2013 – July 2015: [Stiftung Maria Ebene](http://mariaebene.at)

Apprenticeship as an IT Technican over the [FAB](http://www.fab.at), did a lot of Filemaker developements.

#### October 2012 – May 2013: [EPOS Computer](https://www.eposcomputer.com/)

Technical field service as a Apple Service Technican and programming.

#### Januar 2012 – June 2012: ITC Energy AG

Filemaker Development of a ERP.
HTML5 2D CAD Tool.

#### Oktober 2008 – December 2011: [JR IT Solutions](http://jrit.at)

Self employed as Software developer and IT Consultant.

Developed a inhouse ERP Solution for [InAndOut](https://www.inandout-distribution.com/en/) this Solution is still in use in 2023.

#### July 2007 – September 2008: [EPOS Computer](https://www.eposcomputer.com/)

Technical field service as a Apple Service Technican and programming.

#### June 2005 – July 2007: Community service + Employment [Stiftung Maria Ebene](http://mariaebene.at)

IT and software developer.

#### Jan 2004 – May 2005: [ABF/Landeskrankenhaus Feldkirch](http://www.lkhf.at/)

Development of a MS Access Databases.

==> v1.4.43.zip: homepage/content/author/jochum.md <==
---
date: 2023-07-09T00:00:00+02:00
title: René Jochum
description: Is an FOSS enthusiast who has been programming since 2002, currently he loves to develop in Go.
address: Nenzing
email: rene@jochum.dev
phone: +43 664 750 77 653
pgp: F2A7235C1ECFD2F7EADB6D1FF7D906F5E51E8E5E
pgppubfile: /static/author/jochum_pub_pgp.asc

img: /static/author/jochum_240x240.png
---
## About me

I am a passionate programmer with experience in nine different programming languages, of which I excel in three in particular. However, I am not just a technology enthusiast; I am also a social person who enjoys collaborating with others and advocating for their needs.

My experience as a peer has shown me the importance of building positive working relationships and being responsive to the needs of others. I am constantly striving to improve my skills and embrace new challenges to grow both personally and professionally.

### Knowledge

Programming Languages (in order of preference):

Language      | Years of Knowledge
--------------|-------------------------------------------------------------------------
Go            |      [11+](https://github.com/jochumdev/golxml)
Python        |      [13+](https://github.com/jochumdev/socketrpc)
C++           |      [13+](https://github.com/jochumdev/Warzone-QML-Frontend)
PHP           |      20+
Javascript    |      21+
Visual Basic  |      [21+](http://www.vbarchiv.net/tipps/details.php?id=680)
VB.NET        |      14+
C#            |      [10+](https://github.com/jochumdev/SharpFlame)

Operating Systems: Linux, OS-X, Windows

Languages: German (first language), English (fluent)

### OpenSource Activities

#### 2023: [go-micro - Development of the upcoming V5](https://github.com/go-orb/go-micro)

[me](https://github.com/jochumdev) and [@Davincible](https://github.com/Davincible) work on the next version of go-micro.

#### 2022: [MicroLobby - 3rd gen lobbyserver for Warzone 2100](https://github.com/jochumdev/microlobby)

MicroLobby is the next, next gen lobbyserver for Warzone 2100 after wzlobbserver-ng.

For this I also have written [jo-micro/router](https://git.jochum.dev/jo-micro/router) and [jo-micro/auth2](https://git.jochum.dev/jo-micro/auth2).

#### 2021: [lql+api](https://git.jochum.dev/jochum/lql-api) + LetsCheck for CheckMK

A interface to the LQL of CheckMK + a Mobile App written in flutter.

#### 2018: LXD Module and States are now part of Salt Fluorine [original PR](https://github.com/saltstack/salt/pull/46231)

Finaly the LXD Module and its States are now part of Saltstack Fluorine. :)

#### 2016 [Presentation at the Linuxday Vorarlberg (German)](https://www.youtube.com/watch?v=0WIyYOsSvQw)

I hold a presentation about Saltstack at the Linuxday Vorarlberg.

#### 2016 - 2017: [saltstack-lxd-formula](https://github.com/saltstack-formulas/lxd-formula)

Working on automatic deployed LXD containers - You say **you want** a Website - **you get** a container with a website in it and ofc all its routing and stuff.

#### 2015 - ca. 2018: [LXD](https://linuxcontainers.org/lxd/)

Smaller stuff.
Intodruced the new [Storage API](https://github.com/lxc/lxd/commits/main?author=rene@jochums.at) for BTRFS and big parts of the LVM version.

#### 2009 - current: IRC

In german theres a wording "Girl for everything" - I help where I can under the name "jochum".

#### 2010 - 2015: [Warzone 2100](http://www.wz2100.net/)

Hosting and maintenance of the website.
Intodruced the [buildbot](http://buildbot.wz2100.net/).
Introduced a new [Lobby Server](https://github.com/jochumdev/wzlobbyserver-ng) in Python.

#### 2002 - ca. 2006: [Apachefriends](https://www.apachefriends.org) XAMPP

Smaller scripts, Moderation in the forums and smaller work.

#### 2002: vb@rchiv

[.m3u reader](http://www.vbarchiv.net/tipps/details.php?id=680)
[ID3v2 Tag reader](http://www.vbarchiv.net/tipps/details.php?id=676)

### CAREER SUMMARY

#### Mai 2023: [Institut für Sozialdienste gGbmH](https://ifs.at)

IT Technican.

#### Januar 2022 - June 2022: [Jochum Development](https://jochum.dev)

Freelance Developer.

#### August 2018 - Oktober 2021: [Webmeisterei GmbH](https://webmeisterei.com)

Worked as DevOp

Tools I have been working with:

- Saltstack
- Debian
- Nutanix CE
- MariaDB Galera Cluster
- Check_MK
- Kubernetes with Rancher
- Gitlab
- borgbackup with borgmatic
- HyCU Backup

#### Mai 2018 - June 2018: [Proxmox Server Solutions GmbH](https://www.proxmox.com/en)

Development in Perl, mainly developed a Client for Proxmox Virtual Environment.

- [pmxc](https://github.com/jochumdev/pmxc)
- [pve-client](https://git.proxmox.com/?p=pve-client.git;a=shortlog)

#### November 2016 – January 2017: [Stiftung Maria Ebene](http://mariaebene.at)

Developing interfaces between Apps (SAP / Filemaker / ELGA uvm.).

- [py-restfmclient](https://github.com/jochumdev/py-restfmclient) python client library for Filemaker over [RESTfm](http://restfm.com)

#### August 2015 – October 2016: [Webmeisterei GmbH](https://webmeisterei.com)

Worked as Plone developer.

#### June 2013 – July 2015: [Stiftung Maria Ebene](http://mariaebene.at)

Apprenticeship as an IT Technican over the [FAB](http://www.fab.at), did a lot of Filemaker developements.

#### October 2012 – May 2013: [EPOS Computer](https://www.eposcomputer.com/)

Technical field service as a Apple Service Technican and programming.

#### Januar 2012 – June 2012: ITC Energy AG

Filemaker Development of a ERP.
HTML5 2D CAD Tool.

#### Oktober 2008 – December 2011: [JR IT Solutions](http://jrit.at)

Self employed as Software developer and IT Consultant.

Developed a inhouse ERP Solution for [InAndOut](https://www.inandout-distribution.com/en/) this Solution is still in use in 2023.

#### July 2007 – September 2008: [EPOS Computer](https://www.eposcomputer.com/)

Technical field service as a Apple Service Technican and programming.

#### June 2005 – July 2007: Community service + Employment [Stiftung Maria Ebene](http://mariaebene.at)

IT and software developer.

#### Jan 2004 – May 2005: [ABF/Landeskrankenhaus Feldkirch](http://www.lkhf.at/)

Development of a MS Access Databases.
